/*
 * \brief  Platform-specific helper functions for the _main() function
 * \author Norman Feske
 * \author Sebastian Sumpf
 * \date   2009-12-28
 */

/*
 * Copyright (C) 2009-2012 Genode Labs GmbH
 *
 * This file is part of the Genode OS framework, which is distributed
 * under the terms of the GNU General Public License version 2.
 */

#ifndef _PLATFORM___MAIN_HELPER_H_
#define _PLATFORM___MAIN_HELPER_H_

#include <nova/syscalls.h>
#include <base/stdint.h>

/**
 * Initial value of esp register, saved by the crt0 startup code
 *
 * This value contains the address of the hypervisor information page.
 */
extern long __initial_sp;

/**
 * First available capability selector for custom use
 */
extern int __first_free_cap_selector;

static void main_thread_bootstrap()
{
	/* register start of usable capability range */
	enum { FIRST_FREE_PORTAL = 0x1000 };

	/* this variable may be set by the dynamic linker (ldso) */
	if (!__first_free_cap_selector)
		__first_free_cap_selector = FIRST_FREE_PORTAL;
}

#endif /* _PLATFORM___MAIN_HELPER_H_ */
